# 0.6

## New features

* Subslides insertion (`.slide_at()`)
* Custom code syntaxes and code color themes

# 0.5

## New features

* text itself can be `InSteps`
* `ListBox` helper added
* `default_code_language` added (by @fgelm01)
* `default_theme` renamed to `default_code_theme`

# 0.4

## New features

* verbose level & progress bar
